@@ -34,6 +34,8 @@
 #include <tqobject.h>
 #include <tqvaluelist.h>
 
+#include <kdemacros.h>
+
 // forward declarations
 class Smb4KHostItem;
 class Smb4KBookmark;
@@ -46,9 +48,9 @@ class Smb4KBookmark;
  * @author         Alexander Reinholdt <dustpuppy@mail.berlios.de>
  */
 
-class Smb4KBookmarkHandler : public TQObject
+class KDE_EXPORT Smb4KBookmarkHandler : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
