@@ -36,6 +36,8 @@
 #include <tqtimer.h>
 #include <tqvaluelist.h>
 
+#include <kdemacros.h>
+
 // application specific includes
 #include "smb4kscanner.h"
 #include "smb4kmounter.h"
@@ -57,9 +59,9 @@ class Smb4KShare;
  * @author Alexander Reinholdt <dustpuppy@users.berlios.de>
  */
 
-class Smb4KCore : public TQObject
+class KDE_EXPORT Smb4KCore : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
