@@ -37,6 +37,7 @@
 #include <tqfile.h>
 
 // KDE includes
+#include <kdemacros.h>
 #include <kprocess.h>
 
 // application specific includes
@@ -56,9 +57,9 @@ class Smb4KShare;
  * @author Alexander Reinholdt <dustpuppy@users.berlios.de>
  */
 
-class Smb4KMounter : public TQObject
+class KDE_EXPORT Smb4KMounter : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
