@@ -36,6 +36,7 @@
 #include <tqptrqueue.h>
 
 // KDE includes
+#include <kdemacros.h>
 #include <kprocess.h>
 
 // forward declarations
@@ -48,7 +49,7 @@ class Smb4KPreviewItem;
  * @author Alexander Reinholdt <dustpuppy@users.berlios.de>
  */
 
-class Smb4KPreviewer : public TQObject
+class KDE_EXPORT Smb4KPreviewer : public TQObject
 {
   TQ_OBJECT
   
