@@ -36,6 +36,7 @@
 #include <tqptrqueue.h>
 
 // KDE includes
+#include <kdemacros.h>
 #include <kprocess.h>
 
 // application specific includes
@@ -55,9 +56,9 @@ class Smb4KShareItem;
  * @author Alexander Reinholdt <dustpuppy@mail.berlios.de>
  */
 
-class Smb4KScanner : public TQObject
+class KDE_EXPORT Smb4KScanner : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
