@@ -31,8 +31,9 @@
 #endif
 
 // KDE includes
-#include <kprocess.h>
+#include <kdemacros.h>
 #include <kdialogbase.h>
+#include <kprocess.h>
 
 // TQt includes
 #include <tqobject.h>
@@ -51,9 +52,9 @@ class Smb4KSynchronizationInfo;
  */
 
 
-class Smb4KSynchronizer : public TQObject
+class KDE_EXPORT Smb4KSynchronizer : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
