@@ -36,6 +36,7 @@
 #include <tqcstring.h>
 
 // KDE include
+#include <kdemacros.h>
 #include <kprocess.h>
 
 
@@ -46,7 +47,7 @@
  * @author Alexander Reinholdt <dustpuppy@mail.berlios.de>
  */
 
-class Smb4KFileIO : public TQObject
+class KDE_EXPORT Smb4KFileIO : public TQObject
 {
   TQ_OBJECT
   
