@@ -31,6 +31,7 @@
 #endif
 
 // KDE includes
+#include <kdemacros.h>
 #include <kdialogbase.h>
 #include <tdelistview.h>
 #include <tdeactioncollection.h>
@@ -41,9 +42,9 @@
  * @author Alexander Reinholdt <dustpuppy@users.berlios.de>
  */
 
-class Smb4KBookmarkEditor : public KDialogBase
+class KDE_EXPORT Smb4KBookmarkEditor : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
