@@ -35,6 +35,7 @@
 #include <tqcheckbox.h>
 
 // KDE includes
+#include <kdemacros.h>
 #include <kdialogbase.h>
 #include <knuminput.h>
 #include <kcombobox.h>
@@ -44,7 +45,7 @@
 class Smb4KHostItem;
 class Smb4KShareItem;
 
-class Smb4KCustomOptionsDialog : public KDialogBase
+class KDE_EXPORT Smb4KCustomOptionsDialog : public KDialogBase
 {
   TQ_OBJECT
   
