@@ -35,6 +35,7 @@
 #include <tqcheckbox.h>
 
 // KDE includes
+#include <kdemacros.h>
 #include <kdialogbase.h>
 #include <klineedit.h>
 
@@ -44,7 +45,7 @@
  * @author Alexander Reinholdt <dustpuppy@users.berlios.de>
  */
 
-class Smb4KMountDialog : public KDialogBase
+class KDE_EXPORT Smb4KMountDialog : public KDialogBase
 {
   TQ_OBJECT
   
