@@ -34,6 +34,7 @@
 #include <tqvaluelist.h>
 
 // KDE includes
+#include <kdemacros.h>
 #include <kdialogbase.h>
 #include <kiconview.h>
 #include <tdetoolbar.h>
@@ -52,9 +53,9 @@ class Smb4KShareItem;
  * @author Alexander Reinholdt <dustpuppy@users.berlios.de>
  */
 
-class Smb4KPreviewDialog : public KDialogBase
+class KDE_EXPORT Smb4KPreviewDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
