@@ -77,23 +77,23 @@ Smb4KSharesIconViewPart::Smb4KSharesIconViewPart( TQWidget *parentWidget, const
   loadSettings();
 
   // Add some connections:
-  connect( Smb4KCore::mounter(),      TQT_SIGNAL( updated() ),
-           this,                      TQT_SLOT( slotMountedShares() ) );
+  connect( Smb4KCore::mounter(),      TQ_SIGNAL( updated() ),
+           this,                      TQ_SLOT( slotMountedShares() ) );
 
-  connect( Smb4KCore::synchronizer(), TQT_SIGNAL( state( int ) ),
-           this,                      TQT_SLOT( slotSynchronizationState( int ) ) );
+  connect( Smb4KCore::synchronizer(), TQ_SIGNAL( state( int ) ),
+           this,                      TQ_SLOT( slotSynchronizationState( int ) ) );
 
-  connect( m_widget,                  TQT_SIGNAL( contextMenuRequested( TQIconViewItem *, const TQPoint & ) ),
-           this,                      TQT_SLOT( slotContextMenuRequested( TQIconViewItem *, const TQPoint & ) ) );
+  connect( m_widget,                  TQ_SIGNAL( contextMenuRequested( TQIconViewItem *, const TQPoint & ) ),
+           this,                      TQ_SLOT( slotContextMenuRequested( TQIconViewItem *, const TQPoint & ) ) );
 
-  connect( m_widget,                  TQT_SIGNAL( selectionChanged( TQIconViewItem * ) ),
-           this,                      TQT_SLOT( slotSelectionChanged( TQIconViewItem * ) ) );
+  connect( m_widget,                  TQ_SIGNAL( selectionChanged( TQIconViewItem * ) ),
+           this,                      TQ_SLOT( slotSelectionChanged( TQIconViewItem * ) ) );
 
-  connect( m_widget,                  TQT_SIGNAL( pressed( TQIconViewItem * ) ),
-           this,                      TQT_SLOT( slotMouseButtonPressed( TQIconViewItem * ) ) );
+  connect( m_widget,                  TQ_SIGNAL( pressed( TQIconViewItem * ) ),
+           this,                      TQ_SLOT( slotMouseButtonPressed( TQIconViewItem * ) ) );
 
-  connect( m_widget,                  TQT_SIGNAL( executed( TQIconViewItem * ) ),
-           this,                      TQT_SLOT( slotFilemanager() ) );
+  connect( m_widget,                  TQ_SIGNAL( executed( TQIconViewItem * ) ),
+           this,                      TQ_SLOT( slotFilemanager() ) );
 }
 
 
@@ -105,25 +105,25 @@ Smb4KSharesIconViewPart::~Smb4KSharesIconViewPart()
 void Smb4KSharesIconViewPart::setupActions()
 {
   // Create the actions:
-  TDEAction *unmount =   new TDEAction( i18n( "&Unmount" ), "drive-harddisk", TDEShortcut( CTRL+Key_U ),
-                                    this, TQT_SLOT( slotUnmountShare() ),
+  TDEAction *unmount =   new TDEAction( i18n( "&Unmount" ), "drive-harddisk-unmounted", TDEShortcut( CTRL+Key_U ),
+                                    this, TQ_SLOT( slotUnmountShare() ),
                                     actionCollection(), "unmount_action" );
 #ifdef __linux__
-  TDEAction *force =     new TDEAction( i18n( "&Force Unmounting" ), "drive-harddisk", TDEShortcut( CTRL+Key_F ),
-                                    this, TQT_SLOT( slotForceUnmountShare() ),
+  TDEAction *force =     new TDEAction( i18n( "&Force Unmounting" ), "drive-harddisk-unmounted", TDEShortcut( CTRL+Key_F ),
+                                    this, TQ_SLOT( slotForceUnmountShare() ),
                                     actionCollection(), "force_unmount_action" );
 #endif
   TDEAction *all =       new TDEAction( i18n( "U&nmount All" ), "gear", TDEShortcut( CTRL+Key_N ),
-                                    this, TQT_SLOT( slotUnmountAllShares() ),
+                                    this, TQ_SLOT( slotUnmountAllShares() ),
                                     actionCollection(), "unmount_all_action" );
   TDEAction *sync =      new TDEAction( i18n( "S&ynchronize" ), "go-bottom", TDEShortcut( CTRL+Key_Y ),
-                                    this, TQT_SLOT( slotSynchronize() ),
+                                    this, TQ_SLOT( slotSynchronize() ),
                                     actionCollection(), "synchronize_action" );
   TDEAction *konsole =   new TDEAction( i18n( "Open with Konso&le" ), "terminal", TDEShortcut( CTRL+Key_L ),
-                                    this, TQT_SLOT( slotKonsole() ),
+                                    this, TQ_SLOT( slotKonsole() ),
                                     actionCollection(), "konsole_action" );
   TDEAction *konq =      new TDEAction( i18n( "Open with &Konqueror" ), "kfm_home", TDEShortcut( CTRL+Key_K ),
-                                    this, TQT_SLOT( slotFilemanager() ),
+                                    this, TQ_SLOT( slotFilemanager() ),
                                     actionCollection(), "filemanager_action" );
 
   // Disable all actions for now:
@@ -217,7 +217,7 @@ void Smb4KSharesIconViewPart::customEvent( TQCustomEvent *e )
 
 
 /////////////////////////////////////////////////////////////////////////////
-// TQT_SLOT IMPLEMENTATIONS (Smb4KSharesIconViewPart)
+// SLOT IMPLEMENTATIONS (Smb4KSharesIconViewPart)
 /////////////////////////////////////////////////////////////////////////////
 
 void Smb4KSharesIconViewPart::slotContextMenuRequested( TQIconViewItem *item, const TQPoint &pos )
@@ -444,7 +444,7 @@ void Smb4KSharesIconViewPart::slotUnmountAllShares()
 void Smb4KSharesIconViewPart::slotSynchronize()
 {
   Smb4KSharesIconViewItem *item = static_cast<Smb4KSharesIconViewItem *>( m_widget->currentItem() );
-  Smb4KSynchronizationDialog *dlg = static_cast<Smb4KSynchronizationDialog *>( TQT_TQWIDGET(m_widget->child( "SynchronizationDialog", "Smb4KSynchronizationDialog", true )) );
+  Smb4KSynchronizationDialog *dlg = static_cast<Smb4KSynchronizationDialog *>( m_widget->child( "SynchronizationDialog", "Smb4KSynchronizationDialog", true ) );
 
   if ( item && !item->shareObject()->isBroken() && !dlg )
   {
@@ -562,7 +562,7 @@ TDEInstance *Smb4KSharesIconViewPartFactory::instance()
 
 extern "C"
 {
-  void *init_libsmb4ksharesiconview()
+  KDE_EXPORT void *init_libsmb4ksharesiconview()
   {
     TDEGlobal::locale()->insertCatalogue( "smb4k" );
     return new Smb4KSharesIconViewPartFactory;
