@@ -80,23 +80,23 @@ Smb4KSharesListViewPart::Smb4KSharesListViewPart( TQWidget *parentWidget, const
   loadSettings();
 
   // Add some connections:
-  connect( Smb4KCore::mounter(),      TQT_SIGNAL( updated() ),
-           this,                      TQT_SLOT( slotMountedShares() ) );
+  connect( Smb4KCore::mounter(),      TQ_SIGNAL( updated() ),
+           this,                      TQ_SLOT( slotMountedShares() ) );
 
-  connect( Smb4KCore::synchronizer(), TQT_SIGNAL( state( int ) ),
-           this,                      TQT_SLOT( slotSynchronizationState( int ) ) );
+  connect( Smb4KCore::synchronizer(), TQ_SIGNAL( state( int ) ),
+           this,                      TQ_SLOT( slotSynchronizationState( int ) ) );
 
-  connect( m_widget,                  TQT_SIGNAL( contextMenuRequested( TQListViewItem *, const TQPoint & , int) ),
-           this,                      TQT_SLOT( slotContextMenuRequested( TQListViewItem *, const TQPoint &, int ) ) );
+  connect( m_widget,                  TQ_SIGNAL( contextMenuRequested( TQListViewItem *, const TQPoint & , int) ),
+           this,                      TQ_SLOT( slotContextMenuRequested( TQListViewItem *, const TQPoint &, int ) ) );
 
-  connect( m_widget,                  TQT_SIGNAL( selectionChanged( TQListViewItem * ) ),
-           this,                      TQT_SLOT( slotSelectionChanged( TQListViewItem * ) ) );
+  connect( m_widget,                  TQ_SIGNAL( selectionChanged( TQListViewItem * ) ),
+           this,                      TQ_SLOT( slotSelectionChanged( TQListViewItem * ) ) );
 
-  connect( m_widget,                  TQT_SIGNAL( pressed( TQListViewItem * ) ),
-           this,                      TQT_SLOT( slotMouseButtonPressed( TQListViewItem * ) ) );
+  connect( m_widget,                  TQ_SIGNAL( pressed( TQListViewItem * ) ),
+           this,                      TQ_SLOT( slotMouseButtonPressed( TQListViewItem * ) ) );
 
-  connect( m_widget,                  TQT_SIGNAL( executed( TQListViewItem * ) ),
-           this,                      TQT_SLOT( slotFilemanager() ) );
+  connect( m_widget,                  TQ_SIGNAL( executed( TQListViewItem * ) ),
+           this,                      TQ_SLOT( slotFilemanager() ) );
 }
 
 
@@ -108,25 +108,25 @@ Smb4KSharesListViewPart::~Smb4KSharesListViewPart()
 void Smb4KSharesListViewPart::setupActions()
 {
   // Create the actions:
-  TDEAction *unmount =   new TDEAction( i18n( "&Unmount" ), "drive-harddisk", TDEShortcut( CTRL+Key_U ),
-                                    this, TQT_SLOT( slotUnmountShare() ),
+  TDEAction *unmount =   new TDEAction( i18n( "&Unmount" ), "drive-harddisk-unmounted", TDEShortcut( CTRL+Key_U ),
+                                    this, TQ_SLOT( slotUnmountShare() ),
                                     actionCollection(), "unmount_action" );
 #ifdef __linux__
-  TDEAction *force =     new TDEAction( i18n( "&Force Unmounting" ), "drive-harddisk", TDEShortcut( CTRL+Key_F ),
-                                    this, TQT_SLOT( slotForceUnmountShare() ),
+  TDEAction *force =     new TDEAction( i18n( "&Force Unmounting" ), "drive-harddisk-unmounted", TDEShortcut( CTRL+Key_F ),
+                                    this, TQ_SLOT( slotForceUnmountShare() ),
                                     actionCollection(), "force_unmount_action" );
 #endif
   TDEAction *all =       new TDEAction( i18n( "U&nmount All" ), "gear", TDEShortcut( CTRL+Key_N ),
-                                    this, TQT_SLOT( slotUnmountAllShares() ),
+                                    this, TQ_SLOT( slotUnmountAllShares() ),
                                     actionCollection(), "unmount_all_action" );
   TDEAction *sync =      new TDEAction( i18n( "S&ynchronize" ), "go-bottom", TDEShortcut( CTRL+Key_Y ),
-                                    this, TQT_SLOT( slotSynchronize() ),
+                                    this, TQ_SLOT( slotSynchronize() ),
                                     actionCollection(), "synchronize_action" );
   TDEAction *konsole =   new TDEAction( i18n( "Open with Konso&le" ), "terminal", TDEShortcut( CTRL+Key_L ),
-                                    this, TQT_SLOT( slotKonsole() ),
+                                    this, TQ_SLOT( slotKonsole() ),
                                     actionCollection(), "konsole_action" );
   TDEAction *konq =      new TDEAction( i18n( "Open with &Konqueror" ), "kfm_home", TDEShortcut( CTRL+Key_K ),
-                                    this, TQT_SLOT( slotFilemanager() ),
+                                    this, TQ_SLOT( slotFilemanager() ),
                                     actionCollection(), "filemanager_action" );
 
   // Disable all actions for now:
@@ -331,7 +331,7 @@ void Smb4KSharesListViewPart::customEvent( TQCustomEvent *e )
 
 
 /////////////////////////////////////////////////////////////////////////////
-// TQT_SLOT IMPLEMENTATIONS (Smb4KSharesListViewPart)
+// SLOT IMPLEMENTATIONS (Smb4KSharesListViewPart)
 /////////////////////////////////////////////////////////////////////////////
 
 void Smb4KSharesListViewPart::slotContextMenuRequested( TQListViewItem *item, const TQPoint &pos, int /*col*/ )
@@ -578,7 +578,7 @@ void Smb4KSharesListViewPart::slotUnmountAllShares()
 void Smb4KSharesListViewPart::slotSynchronize()
 {
   Smb4KSharesListViewItem *item = static_cast<Smb4KSharesListViewItem *>( m_widget->currentItem() );
-  Smb4KSynchronizationDialog *dlg = static_cast<Smb4KSynchronizationDialog *>( TQT_TQWIDGET(m_widget->child( "SynchronizationDialog", "Smb4KSynchronizationDialog", true )) );
+  Smb4KSynchronizationDialog *dlg = static_cast<Smb4KSynchronizationDialog *>( m_widget->child( "SynchronizationDialog", "Smb4KSynchronizationDialog", true ) );
 
   if ( item && !item->shareObject()->isBroken() && !dlg )
   {
@@ -689,7 +689,7 @@ TDEInstance *Smb4KSharesListViewPartFactory::instance()
 
 extern "C"
 {
-  void *init_libsmb4kshareslistview()
+  KDE_EXPORT void *init_libsmb4kshareslistview()
   {
     TDEGlobal::locale()->insertCatalogue( "smb4k" );
     return new Smb4KSharesListViewPartFactory;
