@@ -65,17 +65,17 @@ Smb4KSearchDialogPart::Smb4KSearchDialogPart( TQWidget *parentWidget, const char
   m_serial_number = 0;
 
   // Connections:
-  connect( m_widget,              TQT_SIGNAL( buttonPressed( int ) ),
-           this,                  TQT_SLOT( slotButtonPressed( int ) ) );
+  connect( m_widget,              TQ_SIGNAL( buttonPressed( int ) ),
+           this,                  TQ_SLOT( slotButtonPressed( int ) ) );
 
-  connect( m_widget->listView(),  TQT_SIGNAL( doubleClicked( TQListViewItem * ) ),
-           this,                  TQT_SLOT( slotItemDoubleClicked( TQListViewItem * ) ) );
+  connect( m_widget->listView(),  TQ_SIGNAL( doubleClicked( TQListViewItem * ) ),
+           this,                  TQ_SLOT( slotItemDoubleClicked( TQListViewItem * ) ) );
 
-  connect( Smb4KCore::scanner(),  TQT_SIGNAL( searchResult( Smb4KHostItem * ) ),
-           this,                  TQT_SLOT( slotReceivedSearchResult( Smb4KHostItem * ) ) );
+  connect( Smb4KCore::scanner(),  TQ_SIGNAL( searchResult( Smb4KHostItem * ) ),
+           this,                  TQ_SLOT( slotReceivedSearchResult( Smb4KHostItem * ) ) );
 
-  connect( Smb4KCore::scanner(),  TQT_SIGNAL( hostListChanged() ),
-           this,                  TQT_SLOT( slotCheckItemIsKnown() ) );
+  connect( Smb4KCore::scanner(),  TQ_SIGNAL( hostListChanged() ),
+           this,                  TQ_SLOT( slotCheckItemIsKnown() ) );
 }
 
 
@@ -111,7 +111,7 @@ void Smb4KSearchDialogPart::customEvent( TQCustomEvent *e )
 
 
 /////////////////////////////////////////////////////////////////////////////
-// TQT_SLOT IMPLEMENTATIONS (Smb4KSearchDialogPart)
+// SLOT IMPLEMENTATIONS (Smb4KSearchDialogPart)
 /////////////////////////////////////////////////////////////////////////////
 
 void Smb4KSearchDialogPart::slotButtonPressed( int button_id )
@@ -267,7 +267,7 @@ TDEInstance *Smb4KSearchDialogPartFactory::instance()
 
 extern "C"
 {
-  void *init_libsmb4ksearchdialog()
+  KDE_EXPORT void *init_libsmb4ksearchdialog()
   {
     TDEGlobal::locale()->insertCatalogue( "smb4k" );
     return new Smb4KSearchDialogPartFactory;
